@@ -26,6 +26,27 @@ class TestGameOutcomeYearCalculator(unittest.TestCase):
         self.assertEqual(0, response[teams[0].id])
         self.assertEqual(1, response[teams[1].id])
 
+    def test_getWins_multiWeekMatchups(self):
+        owners, teams = getNDefaultOwnersAndTeams(2)
+
+        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2, multiWeekMatchupId="1")
+        week1 = Week(weekNumber=1, matchups=[matchup1])
+
+        matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2, multiWeekMatchupId="1")
+        week2 = Week(weekNumber=2, matchups=[matchup2])
+
+        matchup3 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
+        week3 = Week(weekNumber=3, matchups=[matchup3])
+
+        year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2, week3])
+
+        response = GameOutcomeYearCalculator.getWins(year)
+
+        self.assertIsInstance(response, dict)
+        self.assertEqual(2, len(response.keys()))
+        self.assertEqual(0, response[teams[0].id])
+        self.assertEqual(2, response[teams[1].id])
+
     def test_getWins_noneIfNoGamesPlayed(self):
         owners, teams = getNDefaultOwnersAndTeams(3)
 
@@ -192,6 +213,27 @@ class TestGameOutcomeYearCalculator(unittest.TestCase):
         self.assertEqual(1, response[teams[0].id])
         self.assertEqual(0, response[teams[1].id])
 
+    def test_getLosses_multiWeekMatchups(self):
+        owners, teams = getNDefaultOwnersAndTeams(2)
+
+        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2, multiWeekMatchupId="1")
+        week1 = Week(weekNumber=1, matchups=[matchup1])
+
+        matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2, multiWeekMatchupId="1")
+        week2 = Week(weekNumber=2, matchups=[matchup2])
+
+        matchup3 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
+        week3 = Week(weekNumber=3, matchups=[matchup3])
+
+        year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2, week3])
+
+        response = GameOutcomeYearCalculator.getLosses(year)
+
+        self.assertIsInstance(response, dict)
+        self.assertEqual(2, len(response.keys()))
+        self.assertEqual(2, response[teams[0].id])
+        self.assertEqual(0, response[teams[1].id])
+
     def test_getLosses_noneIfNoGamesPlayed(self):
         owners, teams = getNDefaultOwnersAndTeams(3)
 
@@ -358,6 +400,27 @@ class TestGameOutcomeYearCalculator(unittest.TestCase):
         self.assertEqual(1, response[teams[0].id])
         self.assertEqual(1, response[teams[1].id])
 
+    def test_getTies_multiWeekMatchups(self):
+        owners, teams = getNDefaultOwnersAndTeams(2)
+
+        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=1, multiWeekMatchupId="1")
+        week1 = Week(weekNumber=1, matchups=[matchup1])
+
+        matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=1, multiWeekMatchupId="1")
+        week2 = Week(weekNumber=2, matchups=[matchup2])
+
+        matchup3 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=1)
+        week3 = Week(weekNumber=3, matchups=[matchup3])
+
+        year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2, week3])
+
+        response = GameOutcomeYearCalculator.getTies(year)
+
+        self.assertIsInstance(response, dict)
+        self.assertEqual(2, len(response.keys()))
+        self.assertEqual(2, response[teams[0].id])
+        self.assertEqual(2, response[teams[1].id])
+
     def test_getTies_noneIfNoGamesPlayed(self):
         owners, teams = getNDefaultOwnersAndTeams(3)
 
@@ -526,6 +589,27 @@ class TestGameOutcomeYearCalculator(unittest.TestCase):
         self.assertEqual(Deci("0.375"), response[teams[0].id])
         self.assertEqual(Deci("0.625"), response[teams[1].id])
 
+    def test_getWinPercentage_multiWeekMatchups(self):
+        owners, teams = getNDefaultOwnersAndTeams(2)
+
+        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2, multiWeekMatchupId="1")
+        week1 = Week(weekNumber=1, matchups=[matchup1])
+
+        matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=3, teamBScore=4, multiWeekMatchupId="1")
+        week2 = Week(weekNumber=2, matchups=[matchup2])
+
+        matchup3 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=2, teamBScore=1)
+        week3 = Week(weekNumber=3, matchups=[matchup3])
+
+        year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2, week3])
+
+        response = GameOutcomeYearCalculator.getWinPercentage(year)
+
+        self.assertIsInstance(response, dict)
+        self.assertEqual(2, len(response.keys()))
+        self.assertEqual(Deci("0.5"), response[teams[0].id])
+        self.assertEqual(Deci("0.5"), response[teams[1].id])
+
     def test_getWinPercentage_noneIfNoGamesPlayed(self):
         owners, teams = getNDefaultOwnersAndTeams(3)
 
@@ -698,6 +782,27 @@ class TestGameOutcomeYearCalculator(unittest.TestCase):
         self.assertEqual(Deci("0.5"), response[teams[0].id])
         self.assertEqual(Deci("2.5"), response[teams[1].id])
 
+    def test_getWAL_multiWeekMatchups(self):
+        owners, teams = getNDefaultOwnersAndTeams(2)
+
+        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2, multiWeekMatchupId="1")
+        week1 = Week(weekNumber=1, matchups=[matchup1])
+
+        matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=3, teamBScore=4, multiWeekMatchupId="1")
+        week2 = Week(weekNumber=2, matchups=[matchup2])
+
+        matchup3 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
+        week3 = Week(weekNumber=3, matchups=[matchup3])
+
+        year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2, week3])
+
+        response = GameOutcomeYearCalculator.getWAL(year)
+
+        self.assertIsInstance(response, dict)
+        self.assertEqual(2, len(response.keys()))
+        self.assertEqual(Deci("0"), response[teams[0].id])
+        self.assertEqual(Deci("2"), response[teams[1].id])
+
     def test_getWAL_noneIfNoGamesPlayed(self):
         owners, teams = getNDefaultOwnersAndTeams(3)
 
@@ -870,6 +975,27 @@ class TestGameOutcomeYearCalculator(unittest.TestCase):
         self.assertEqual(Deci("0.1666666666666666666666666667"), response[teams[0].id])
         self.assertEqual(Deci("0.8333333333333333333333333333"), response[teams[1].id])
 
+    def test_getWALPerGame_multiWeekMatchups(self):
+        owners, teams = getNDefaultOwnersAndTeams(2)
+
+        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2, multiWeekMatchupId="1")
+        week1 = Week(weekNumber=1, matchups=[matchup1])
+
+        matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=3, teamBScore=4, multiWeekMatchupId="1")
+        week2 = Week(weekNumber=2, matchups=[matchup2])
+
+        matchup3 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
+        week3 = Week(weekNumber=3, matchups=[matchup3])
+
+        year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2, week3])
+
+        response = GameOutcomeYearCalculator.getWALPerGame(year)
+
+        self.assertIsInstance(response, dict)
+        self.assertEqual(2, len(response.keys()))
+        self.assertEqual(Deci("0"), response[teams[0].id])
+        self.assertEqual(Deci("1"), response[teams[1].id])
+
     def test_getWALPerGame_noneIfNoGamesPlayed(self):
         owners, teams = getNDefaultOwnersAndTeams(3)
 
